import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcConnectionSource;
import com.j256.ormlite.support.ConnectionSource;

import java.sql.SQLException;
import java.util.Scanner;

public class AccountApp {

    // we are using a MySQl database
    private final static String DATABASE_URL = "jdbc:mysql://localhost:3306/orm_lab?useUnicode=true";

    private Dao<Account, Integer> accountDao;

    public static void main(String[] args) throws Exception {

        // turn our static method into an instance of Main
        new AccountApp().doMain(args);
    }

    private void doMain(String[] args) throws Exception {
        ConnectionSource connectionSource = null;

        try {
            // create our data-source for the database
            connectionSource = new JdbcConnectionSource(DATABASE_URL, "root", "");
            // setup our  DAOs
            setupDao(connectionSource);
            // read, write and delete some data
            processData();

            System.out.println("\n\nIt seems to have worked\n\n");

        } finally {
            // destroy the data source which should close underlying connections
            if (connectionSource != null) {
                connectionSource.close();
            }
        }
    }


    private void processData() throws Exception {
        boolean flag = true;

        while (flag) {

            System.out.println("Select C, R, U, D or exit");
            Scanner scanner = new Scanner(System.in);
            String input = scanner.nextLine();


            if (input.equalsIgnoreCase("exit")) {
                flag = false;
            } else {
                selectOptions(input);
            }
        }
    }


    public void selectOptions(String input) throws Exception {
        if (input.equalsIgnoreCase("C"))
            create();
        else if (input.equalsIgnoreCase("R"))
            read();
        else if (input.equalsIgnoreCase("U"))
            update();
        else if (input.equalsIgnoreCase("D"))
            delete();
        else {
            System.out.println("Select C, R, U, D or exit");
        }
    }


    public void create() throws Exception {

        Scanner input = new Scanner(System.in);

        System.out.println("Enter name");
        String name = input.nextLine();


        System.out.println("Enter password");
        String password = input.nextLine();

        Account account = new Account(name, password);

        accountDao.create(account);

        System.out.println("ID created: " + account.getId());
    }

    public void read() throws SQLException {

        Scanner input = new Scanner(System.in);

        System.out.println("Enter ID");
        int id = input.nextInt();

        Account account = accountDao.queryForId(id);

        String name = account.getName();
        String password = account.getPassword();
        System.out.println(name + " " + password);
    }


    public void update() throws SQLException {

        Scanner scanner = new Scanner(System.in);

        System.out.println("Enter ID");
        int id = scanner.nextInt();

        Account account = accountDao.queryForId(id);

        System.out.println("Select name or password");

        boolean flag = true;
        while (flag) {
            String input = scanner.next();
            if (input.equalsIgnoreCase("name")) {
                System.out.println("Enter name");
                String name = scanner.next();
                account.setName(name);
                flag = false;
            }
            else if (input.equalsIgnoreCase("password")){
                System.out.println("Enter password");
                String password = scanner.next();
                account.setPassword(password);
                flag = false;
            }
            else
            System.out.println("Select name or password");
        }
        accountDao.update(account);
    }


    public void delete() throws SQLException {

        Scanner input = new Scanner(System.in);
        System.out.println("Enter ID");
        int id = input.nextInt();

        accountDao.deleteById(id);
    }


    /**
     * Setup our  DAOs
     */

    private void setupDao(ConnectionSource connectionSource) throws Exception {

        accountDao = DaoManager.createDao(connectionSource, Account.class);

    }
}